# Sindri Python SDK

***This SDK is an alpha (testing) release and may change at any time.***

## Build Status

![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/sindri-labs/sindri-python/build-publish-pypi.yml?style=for-the-badge)

## Description
The Sindri Python SDK.
Contains SDK code for Sindri APIs. Please see [sindri.app](https://sindri.app) for more details.

## Documentation and Usage
Documentation for this repo is automatically generated from the Python docstrings using [lazydocs](https://pypi.org/project/lazydocs/) and published to [sindri.app/docs/reference/sdk/](https://sindri.app/docs/reference/sdk/python) along with the rest of the documentation for Sindri.

## License
[![](https://img.shields.io/github/license/sindri-labs/sindri-python?style=for-the-badge)](https://img.shields.io/github/license/sindri-labs/sindri-python?style=for-the-badge)

`sindri-python` is licensed under a [MIT License](LICENSE) and is copyright [Sindri Labs, Inc.](https://sindri.app).

## Unit Tests
See [`tests/README.md`](tests/README.md) for more information.